import { PLUGIN_ID } from './global';

export interface PluginConfigLookupItem {
  lookupFieldCode: string;
  srcAttachmentFieldCode: string;
  destAttachmentFieldCode: string;
}

export type PluginConfigLookup = PluginConfigLookupItem[];

export interface PluginConfig {
  lookup: PluginConfigLookup;
}

const encodeConfigLookup = (rows: PluginConfigLookup): string => {
  return JSON.stringify(rows);
};

const decodeConfigLookup = (lookup: string): PluginConfigLookup | null => {
  try {
    return JSON.parse(lookup) as PluginConfigLookup;
  } catch (e) {
    return null;
  }
};

export const loadPluginConfigLookup = (): PluginConfigLookup | null => {
  const config = kintone.plugin.app.getConfig(PLUGIN_ID);
  return decodeConfigLookup(config.lookup);
};

export const loadPluginConfig = (): PluginConfig | null => {
  const config = kintone.plugin.app.getConfig(PLUGIN_ID);
  const lookup = decodeConfigLookup(config.lookup);
  return lookup ? { lookup } : null;
};

export const savePluginConfigLookup = (lookup: PluginConfigLookup, callback: () => void) => {
  kintone.plugin.app.setConfig({ lookup: encodeConfigLookup(lookup) }, callback);
};

export const savePluginConfig = (config: PluginConfig, callback: () => void) => {
  kintone.plugin.app.setConfig({ lookup: encodeConfigLookup(config.lookup) }, callback);
};
